==> timi-dev-1.0.1.zip: pay/src/pages/recharge/index.tsx <==
import React, { useEffect, useState } from 'react';
import { request, history } from 'umi';
import UserCard from '@/components/UserCard';
import { unstable_Toast as Toast, unstable_Modal as Modal, unstable_InputItem as InputItem } from '@ant-design/mobile';
import classnames from 'classnames';
import styles from './index.less';
import { connect } from 'react-redux';
import { getUserByUserNoOrNiceNo } from '@/serve/api'
function RechargeItem(props: any) {
  const classes = [styles.rechargeItem];
  if (props.selected) {
    classes.push(styles.selected);
  }
  return (
    <div className={classnames(classes)} onClick={props.onClick}>
      <div className={styles.name}>{props.name}</div>
      <div className={styles.price}>
        <span>￥</span>
        {props.price}
      </div>
    </div>
  );
}

function PayWayItem(props: any) {
  const classes = [styles.payWayItem];
  if (props.selected) {
    classes.push(styles.selected);
  }
  return (
    <div className={classnames(classes)} onClick={props.onClick}><img src={props.icon} width={20} height={20} />&nbsp;&nbsp;{props.name}</div>
  )
}
type _params = {
  params: number
};
function Recharge(props: any) {
  const [itemSelected, setItemSelected] = useState<any>(0);
  const [payWaySelected, setPayWaySelected] = useState<any>(202);
  const [rechargeItems, setRechargeItems] = useState<any>([]);
  const [wxRechargeItems, setWxRechargeItems] = useState<any>([]);
  const [isCustomer, setIsCustomer] = useState<boolean>(false);
  const [isOperation, setIsOperation] = useState<boolean>(false);
  const [isContent, setIsContent] = useState<boolean>(true);
  const [rechargeUserNo, setRechargeUserNo] = useState<any>('');
  const [rechargeUserInfor, setRechargeUserInfor] = useState<any>(null);
  const [userInfo, setUserinfo] = useState<any>(null);
  //获取充值的选项
  const fetchRechargeItems = async () => {
    try {
      const { success, data } = await request('/api-app/v1/recharge/getCoinRechargeItemsGuest');
      if (success) {
        const list = data.list;
        for (let i in list) {
          if (list[i].payWay == 202) {
            // setRechargeItems([...list[i].items, ...list[i].items, ...list[i].items, ...list[i].items, ...list[i].items]);
            setRechargeItems(list[i].items);
            setItemSelected(list[i].items[0]);
          } else if (list[i].payWay == 303) {
            setWxRechargeItems(list[i].items);
          }
        }
      }
    } catch (error) {
      console.log(error);
    }
  };
  useEffect(() => {
    // 拉取充值项目
    fetchRechargeItems();
    let userInfo = window.localStorage.getItem('userInfo');
    let medium = userInfo ? JSON.parse(userInfo) : null;
    if (medium) {
      setUserinfo(medium);
      if (!medium.isAuth) {
        setIsOperation(true);
        setIsContent(false);
      }
    }
  }, []);
  //支付提交按钮
  const payItem = async () => {
    const _payWay = payWaySelected
    // 判断是否登录
    if (!userInfo) {
      history.push(`/login?cb=${encodeURIComponent(location.pathname)}`);
      return;
    }
    if (!userInfo.isAuth) {
      setIsOperation(true);
      setIsContent(false);
      return;
    }
    if (!itemSelected || !itemSelected.itemId) {
      Toast.warn({
        content: '请选择要充值的项目',
      });
      return;
    }
    // 创建订单
    const res = await request(
      '/api-app/v1/recharge/addCoinRechargeOrderGuest',
      {
        method: 'POST',
        requestType: 'form',
        data: {
          itemId: itemSelected.itemId,
          userId: rechargeUserInfor ? rechargeUserInfor.userId : userInfo.userId,
        },
      },
    );
    if (res.success) {
      const payRes = await request('/api-app/v1/pay/addPayOrderGuest', {
        method: 'POST',
        requestType: 'form',
        data: {
          orderId: res.data.orderId,
        },
      });
      if (payRes.success) {
        if (_payWay == 202) {
          const newWindow = window.open('', '_self');
          if (newWindow != null) {
            newWindow.document.write(payRes.data.payParams);
            newWindow.focus();
          }
        } else {
          const resObj = JSON.parse(payRes.data.payParams)
          window.location.href = resObj.mwebUrl + '&redirect_url=' + encodeURIComponent('https://pay.timichat.com/recharge' + `/callback/wechat?userId=${userInfo.userNo}`)
        }
      }
    }
  };

  function onPayWayChange(payWay: Number) {
    setPayWaySelected(payWay)
    if (payWay == 202) {
      setItemSelected(rechargeItems[0])
    } else {
      setItemSelected(wxRechargeItems[0])
    }
  }

  //提示关闭
  const onClose = () => {
    setIsOperation(false)
    setIsContent(false)
  }
  //修改充值用户
  const onShowInputUser = () => {
    if (!userInfo.isAuth) {
      setIsOperation(true);
      setIsContent(false);
      return;
    }
    setIsOperation(true);
    setIsContent(true)
  }
  //关闭修改
  const onCancel = () => {
    setIsOperation(false);
  }
  //获取充值用户信息
  const getUserinfor = async () => {
    try {
      setIsOperation(false);
      let platform: _params;
      platform = {
        params: rechargeUserNo
      }
      const { success, data } = await getUserByUserNoOrNiceNo(platform);
      if (success && data) {
        setRechargeUserInfor(data);
      }
      else {
        Toast.fail({ content: '未查询到用户', duration: 1 })
      }
    } catch (error) {
      console.log(error);
    }
  }
  return (
    <div className={styles.wrap} >
      <UserCard user={props.user} onShowInputUser={onShowInputUser} rechargeUserInfor={rechargeUserInfor} />
      <div className={styles.payWayItems}>
        <PayWayItem icon={require('../../assets/icon_alipay.png')} name='支付宝' selected={payWaySelected == 202} onClick={() => onPayWayChange(202)} />
        <PayWayItem icon={require('../../assets/icon_wechat.png')} name='微信支付' selected={payWaySelected == 303} onClick={() => onPayWayChange(303)} />
      </div>
      <div className={styles.rechargeItems}>
        {(payWaySelected == 202 ? rechargeItems : wxRechargeItems).map((item: any) => (
          <RechargeItem
            key={item.itemId}
            name={`${item.itemCoin}钻石`}
            price={item.itemPrice}
            selected={itemSelected.itemId == item.itemId}
            onClick={() => setItemSelected(item)}
          />
        ))}
      </div>
      <div className={styles.agreement}>
        充值阅读并同意 {'《'}<a href="http://doc.timichat.com/user.html">用户协议&免责声明</a>{'》'}
      </div>
      <div
        style={{ color: '#333333', fontFamily: 'PingFangSC-Regular' }}
        className={styles.agreement}
      >
        1、用户充值前必须登录账号并核对账号信息的一致性，充值成功后不可提现或退款；<br />
        2、未成年人充值的，应征得监护人的同意，否则，请勿充值；<br />
        3、请勿轻信兼职赚钱、刷单返利、低价购买等虚假言论，请勿为陌生人充值，谨防上当受骗；如有问题请<span
          style={{ color: '#5D26FF' }}
          onClick={() => setIsCustomer(true)}
        >联系客服</span>
      </div>
      <div style={{ color: '#333333', fontFamily: 'PingFangSC-Regular' }} className={styles.agreement}>
        请您在充值前仔细阅读{'《'}<a href="http://doc.timichat.com/user.html">用户协议&免责声明</a>{'》'}及温馨提示内容，您点击具体的充值选项并进行充值操作的，视为您已知晓并同意{'《'}<a href="http://doc.timichat.com/user.html">用户协议&免责声明</a>{'》'}及温馨提示的全部内容。
              </div>
      <div className={styles.pay}>
        <div className={styles.button} onClick={payItem}>
          支付
        </div>
      </div>
      <div style={{ display: isCustomer ? 'block' : 'none' }} className={styles.customer}>
        <div className={styles.container}>
          <div className={styles.content}>
            <img src={require('../../assets/erweima.png')} alt="error" />
            <div>如有问题请使用微信扫描二维码进入公众号联系客服</div>
            <div onClick={() => setIsCustomer(false)}>知道了</div>
          </div>
        </div>
      </div>
      <div style={{ display: isOperation ? 'block' : 'none' }} className={styles.operation_mask}>
        <div className={styles.container}>
          <div className={styles.content}>
            {isContent ?
              <div className={styles.user_input}>
                <div className={styles.title}>填写ID</div>
                <InputItem
                  className={styles.input}
                  placeholder="请输入账号ID"
                  defaultValue={rechargeUserNo}
                  onChange={value => setRechargeUserNo(value)}
                />
                <div className={styles.footer_input}>
                  <div onClick={onCancel} >取消</div>
                  <div onClick={getUserinfor}>确定</div>
                </div>
              </div> :
              <div className={styles.auth}>
                <div className={styles.title}>温馨提示</div>
                <div className={styles.main}>当前账号未完成实名认证，请前往APP完成实名认证后再充值</div>
                <div className={styles.footer} onClick={onClose}  >确定</div>
              </div>}
          </div>
        </div>
      </div>
    </div>
  );
}

function mapStateToProps({ global }: any) {
  return { ...global };
}
export default connect(mapStateToProps)(Recharge);

==> timi-dev-1.0.4.zip: pay/src/pages/recharge/index.tsx <==
import React, { useEffect, useState } from 'react';
import { request, history } from 'umi';
import UserCard from '@/components/UserCard';
import {
  unstable_Toast as Toast,
  unstable_Modal as Modal,
  unstable_InputItem as InputItem,
} from '@ant-design/mobile';
import classnames from 'classnames';
import styles from './index.less';
import { connect } from 'react-redux';
import { getUserByUserNoOrNiceNo, getUserIsAuth } from '@/serve/api';
function RechargeItem(props: any) {
  const classes = [styles.rechargeItem];
  if (props.selected) {
    classes.push(styles.selected);
  }
  return (
    <div className={classnames(classes)} onClick={props.onClick}>
      <div className={styles.name}>{props.name}</div>
      <div className={styles.price}>
        <span>￥</span>
        {props.price}
      </div>
    </div>
  );
}

function PayWayItem(props: any) {
  const classes = [styles.payWayItem];
  const { tag } = props;
  if (props.selected) {
    classes.push(styles.selected);
  }
  return (
    <div className={classnames(classes)} onClick={props.onClick}>
      <img src={props.icon} width={20} height={20} />
      &nbsp;&nbsp;{props.name}
      {tag ? <span className={styles.activity_text}>{tag}</span> : null}
    </div>
  );
}
type _params = {
  params: number;
};
function Recharge(props: any) {
  const [itemSelected, setItemSelected] = useState<any>(0);
  const [payWaySelected, setPayWaySelected] = useState<any>(202);
  const [rechargeItems, setRechargeItems] = useState<any>([]);
  const [wxRechargeItems, setWxRechargeItems] = useState<any>([]);
  const [isCustomer, setIsCustomer] = useState<boolean>(false);
  const [isOperation, setIsOperation] = useState<boolean>(false);
  const [isContent, setIsContent] = useState<boolean>(true);
  const [rechargeUserNo, setRechargeUserNo] = useState<any>('');
  const [rechargeUserInfor, setRechargeUserInfor] = useState<any>(null);
  const [userInfo, setUserinfo] = useState<any>(null);
  const [tag, setTagvalue] = useState<string>('');
  //获取充值的选项
  const fetchRechargeItems = async () => {
    try {
      const { success, data } = await request(
        '/api-app/v1/recharge/getCoinRechargeItemsGuest',
      );
      if (success) {
        const list = data.list;
        for (let i in list) {
          if (list[i].payWay == 202) {
            setRechargeItems(list[i].items);
            setItemSelected(list[i].items[0]);
            setTagvalue(list[i].tag);
          } else if (list[i].payWay == 303) {
            setWxRechargeItems(list[i].items);
          }
        }
      }
    } catch (error) {
      console.log(error);
    }
  };
  useEffect(() => {
    // 拉取充值项目
    fetchRechargeItems();
    let userInfo = window.localStorage.getItem('userInfo');
    let medium = userInfo ? JSON.parse(userInfo) : null;
    if (medium) {
      setUserinfo(medium);
    }
  }, []);
  //支付提交按钮
  const payItem = async () => {
    const _payWay = payWaySelected;
    // 判断是否登录
    if (!userInfo) {
      history.push(`/login?cb=${encodeURIComponent(location.pathname)}`);
      return;
    }
    if (Number(itemSelected.itemPrice) > 100) {
      const { success, data } = await getUserIsAuth({
        userId: userInfo?.userId,
      });
      if (success && data) {
        if (!data?.isAuth) {
          setIsOperation(true);
          setIsContent(false);
          return;
        }
      }
    }
    if (!itemSelected || !itemSelected.itemId) {
      Toast.warn({
        content: '请选择要充值的项目',
      });
      return;
    }
    // 创建订单
    const res = await request(
      '/api-app/v1/recharge/addCoinRechargeOrderGuest',
      {
        method: 'POST',
        requestType: 'form',
        data: {
          itemId: itemSelected.itemId,
          userId: rechargeUserInfor
            ? rechargeUserInfor.userId
            : userInfo.userId,
        },
      },
    );
    if (res.success) {
      const payRes = await request('/api-app/v1/pay/addPayOrderGuest', {
        method: 'POST',
        requestType: 'form',
        data: {
          orderId: res.data.orderId,
        },
      });
      if (payRes.success) {
        if (_payWay == 202) {
          const newWindow = window.open('', '_self');
          if (newWindow != null) {
            newWindow.document.write(payRes.data.payParams);
            newWindow.focus();
          }
        } else {
          const resObj = JSON.parse(payRes.data.payParams);
          window.location.href =
            resObj.mwebUrl +
            '&redirect_url=' +
            encodeURIComponent(
              'https://pay.timichat.com/recharge' +
                `/callback/wechat?userId=${userInfo.userNo}`,
            );
        }
      }
    }
  };

  function onPayWayChange(payWay: Number) {
    setPayWaySelected(payWay);
    if (payWay == 202) {
      setItemSelected(rechargeItems[0]);
    } else {
      setItemSelected(wxRechargeItems[0]);
    }
  }

  //提示关闭
  const onClose = () => {
    setIsOperation(false);
    setIsContent(false);
  };
  //修改充值用户
  const onShowInputUser = () => {
    setIsOperation(true);
    setIsContent(true);
  };
  //关闭修改
  const onCancel = () => {
    setIsOperation(false);
  };
  //获取充值用户信息
  const getUserinfor = async () => {
    try {
      setIsOperation(false);
      let platform: _params;
      platform = {
        params: rechargeUserNo,
      };
      const { success, data } = await getUserByUserNoOrNiceNo(platform);
      if (success && data) {
        setRechargeUserInfor(data);
      } else {
        Toast.fail({ content: '未查询到用户', duration: 1 });
      }
    } catch (error) {
      console.log(error);
    }
  };
  return (
    <div className={styles.wrap}>
      <UserCard
        user={props.user}
        onShowInputUser={onShowInputUser}
        rechargeUserInfor={rechargeUserInfor}
      />
      <div className={styles.payWayItems}>
        <PayWayItem
          icon={require('../../assets/icon_alipay.png')}
          name="支付宝"
          selected={payWaySelected == 202}
          onClick={() => onPayWayChange(202)}
          tag={tag}
        />
        <PayWayItem
          icon={require('../../assets/icon_wechat.png')}
          name="微信支付"
          selected={payWaySelected == 303}
          onClick={() => onPayWayChange(303)}
        />
      </div>
      <div className={styles.rechargeItems}>
        {(payWaySelected == 202 ? rechargeItems : wxRechargeItems).map(
          (item: any) => (
            <RechargeItem
              key={item.itemId}
              name={`${item.itemCoin}钻石`}
              price={item.itemPrice}
              selected={itemSelected.itemId == item.itemId}
              onClick={() => setItemSelected(item)}
            />
          ),
        )}
      </div>
      <div className={styles.agreement}>
        充值阅读并同意 {'《'}
        <a href="http://doc.timichat.com/user.html">用户服务协议</a>
        {'》'}
      </div>
      <div
        style={{ color: '#333333', fontFamily: 'PingFangSC-Regular' }}
        className={styles.agreement}
      >
        1、用户充值前必须登录账号并核对账号信息的一致性，充值成功后不可提现或退款；
        <br />
        2、未成年人充值的，应征得监护人的同意，否则，请勿充值；
        <br />
        3、请勿轻信兼职赚钱、刷单返利、低价购买等虚假言论，请勿为陌生人充值，谨防上当受骗；如有问题请
        <span style={{ color: '#5D26FF' }} onClick={() => setIsCustomer(true)}>
          联系客服
        </span>
      </div>
      <div
        style={{ color: '#333333', fontFamily: 'PingFangSC-Regular' }}
        className={styles.agreement}
      >
        请您在充值前仔细阅读{'《'}
        <a href="http://doc.timichat.com/user.html">用户服务协议</a>
        {'》'}
        及温馨提示内容，您点击具体的充值选项并进行充值操作的，视为您已知晓并同意
        {'《'}
        <a href="http://doc.timichat.com/user.html">用户服务协议</a>
        {'》'}及温馨提示的全部内容。
      </div>
      <div className={styles.pay}>
        <div className={styles.button} onClick={payItem}>
          支付
        </div>
      </div>
      <div
        style={{ display: isCustomer ? 'block' : 'none' }}
        className={styles.customer}
      >
        <div className={styles.container}>
          <div className={styles.content}>
            <img src={require('../../assets/erweima.png')} alt="error" />
            <div>如有问题请使用微信扫描二维码进入公众号联系客服</div>
            <div onClick={() => setIsCustomer(false)}>知道了</div>
          </div>
        </div>
      </div>
      <div
        style={{ display: isOperation ? 'block' : 'none' }}
        className={styles.operation_mask}
      >
        <div className={styles.container}>
          <div className={styles.content}>
            {isContent ? (
              <div className={styles.user_input}>
                <div className={styles.title}>填写ID</div>
                <InputItem
                  className={styles.input}
                  placeholder="请输入账号ID"
                  defaultValue={rechargeUserNo}
                  onChange={(value) => setRechargeUserNo(value)}
                />
                <div className={styles.footer_input}>
                  <div onClick={onCancel}>取消</div>
                  <div onClick={getUserinfor}>确定</div>
                </div>
              </div>
            ) : (
              <div className={styles.auth}>
                <div className={styles.title}>温馨提示</div>
                <div className={styles.main}>
                  当前账号未完成实名认证，请前往APP完成实名认证后再充值
                </div>
                <div className={styles.footer} onClick={onClose}>
                  确定
                </div>
              </div>
            )}
          </div>
        </div>
      </div>
    </div>
  );
}

function mapStateToProps({ global }: any) {
  return { ...global };
}
export default connect(mapStateToProps)(Recharge);
